Add support for signalling=auto in zapata.conf.
Index: asterisk-zap_signal_auto/channels/chan_zap.c
===================================================================
--- asterisk-zap_signal_auto.orig/channels/chan_zap.c	2008-01-05 23:18:05.020382823 +0200
+++ asterisk-zap_signal_auto/channels/chan_zap.c	2008-01-05 23:29:24.559107522 +0200
@@ -725,6 +725,7 @@ struct zt_chan_conf {
 	struct zt_ss7 ss7;
 #endif
 	ZT_PARAMS timing;
+	int is_sig_auto; /*!< Use channel signalling from Zaptel? */
 
 	char smdi_port[SMDI_MAX_FILENAME_LEN];
 };
@@ -7862,6 +7863,16 @@ static struct zt_ss7 * ss7_resolve_links
 }
 #endif /* HAVE_SS7 */
 
+/* converts a zaptel sigtype to signalling as can be configured from
+ * zapata.conf.
+ * While both have basically the same values, this will later be the
+ * place to add filters and sanity checks
+ */
+static int sigtype_to_signalling(int sigtype)
+{
+        return sigtype;
+}
+
 static struct zt_pvt *mkintf(int channel, struct zt_chan_conf conf, struct zt_pri *pri, int reloading)
 {
 	/* Make a zt_pvt structure for this interface (or CRV if "pri" is specified) */
@@ -7939,6 +7950,8 @@ static struct zt_pvt *mkintf(int channel
 					destroy_zt_pvt(&tmp);
 					return NULL;
 				}
+				if (conf.is_sig_auto)
+					conf.chan.sig = sigtype_to_signalling(p.sigtype);
 				if (p.sigtype != (conf.chan.sig & 0x3ffff)) {
 					ast_log(LOG_ERROR, "Signalling requested on channel %d is %s but line is in %s signalling\n", channel, sig2str(conf.chan.sig), sig2str(p.sigtype));
 					destroy_zt_pvt(&tmp);
@@ -12755,7 +12768,7 @@ static int build_channels(struct zt_chan
 	int trunkgroup, y;
 #endif
 	
-	if ((reload == 0) && (conf.chan.sig < 0)) {
+	if ((reload == 0) && (conf.chan.sig < 0) && !conf.is_sig_auto) {
 		ast_log(LOG_ERROR, "Signalling must be specified before any channels are.\n");
 		return -1;
 	}
@@ -13149,8 +13162,10 @@ static int process_zap(struct zt_chan_co
 			 if (!strcasecmp(v->name, "signalling") || !strcasecmp(v->name, "signaling")) {
 				int orig_radio = confp->chan.radio;
 				int orig_outsigmod = confp->chan.outsigmod;
+				int orig_auto = confp->is_sig_auto;
 				confp->chan.radio = 0;
 				confp->chan.outsigmod = -1;
+				confp->is_sig_auto = 0;
 				if (!strcasecmp(v->value, "em")) {
 					confp->chan.sig = SIG_EM;
 				} else if (!strcasecmp(v->value, "em_e1")) {
@@ -13260,9 +13275,12 @@ static int process_zap(struct zt_chan_co
 				} else if (!strcasecmp(v->value, "ss7")) {
 					confp->chan.sig = SIG_SS7;
 #endif
+				} else if (!strcasecmp(v->value, "auto")) {
+					confp->is_sig_auto = 1;
 				} else {
 					confp->chan.outsigmod = orig_outsigmod;
 					confp->chan.radio = orig_radio;
+					confp->is_sig_auto = orig_auto;
 					ast_log(LOG_ERROR, "Unknown signalling method '%s'\n", v->value);
 				}
 			 } else if (!strcasecmp(v->name, "outsignalling") || !strcasecmp(v->name, "outsignaling")) {
Index: asterisk-zap_signal_auto/configs/zapata.conf.sample
===================================================================
--- asterisk-zap_signal_auto.orig/configs/zapata.conf.sample	2008-01-05 22:37:46.382552685 +0200
+++ asterisk-zap_signal_auto/configs/zapata.conf.sample	2008-01-05 23:28:12.555004165 +0200
@@ -198,6 +198,7 @@
 ; pritimer cannot be changed on a reload.
 ;
 ; Signalling method.  Valid values:
+; auto:           Use the current value from Zaptel.
 ; em:             E & M
 ; em_e1:          E & M E1
 ; em_w:           E & M Wink
